@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Account Invoice',
+    'name_bg_BG': 'Фактуриране',
     'name_de_DE': 'Fakturierung',
     'name_es_CO': 'Facturación',
     'name_es_ES': 'Facturación',
     'name_fr_FR': 'Facturation',
-    'version': '1.8.0',
+    'name_nl_NL': 'Facturatie',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -19,6 +21,16 @@ With the possibilities:
     - to follow the payment of the invoices.
     - to define invoice sequences on fiscal year or period.
     - to credit any invoice.
+''',
+    'description_bg_BG': '''Финансов и счетоводен модул с:
+    - Условия за плащане
+    - Фактура / Кредитно известие
+    - Фактура за доставчик / Кредитно известие за доставчик
+
+Има следните възможности:
+    - проследяване на плащания на фактури
+    - задаване на последователности на фактура за финансова година или период
+    - кредитиране на всяка фактура
 ''',
     'description_de_DE': '''Modul für Buchhaltung und Fakturierung mit:
     - Definition von Zahlungsbedingungen
@@ -59,6 +71,18 @@ Avec la possibilité:
     - de suivre le paiment des factures
     - de définir les numérotations de facture par période ou par année fiscale
     - de créditer n'importe quelle facture
+    
+''',
+    'description_nl_NL': '''Module voor facturering met:
+    - Betalingstermijnen
+    - Verkoopfacturen / Credit verkoopnota's
+    - Inkoopfacturen / Credit inkoopnota's
+
+Met de mogelijkheid tot:
+    - het volgen van betalingen.
+    - het definiëren van factuurreeksen per boekjaar.
+    - het crediteren van een factuur.
+    
 ''',
     'depends': [
         'ir',
@@ -78,9 +102,11 @@ Avec la possibilité:
         'account.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'nl_NL.csv',
     ]
 }
