@@ -1,12 +1,13 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from trytond.model import ModelView, ModelSQL, fields
-from trytond.backend import TableHandler
-from trytond.pyson import Not, Equal, Eval
 from decimal import Decimal
 import datetime
 import time
 from dateutil.relativedelta import relativedelta
+from trytond.model import ModelView, ModelSQL, fields
+from trytond.backend import TableHandler
+from trytond.pyson import Not, Equal, Eval
+from trytond.transaction import Transaction
 
 
 class PaymentTerm(ModelSQL, ModelView):
@@ -27,11 +28,10 @@ class PaymentTerm(ModelSQL, ModelView):
             'missing_remainder': 'Payment term missing a remainder line!',
             })
 
-    def default_active(self, cursor, user, context=None):
+    def default_active(self):
         return True
 
-    def compute(self, cursor, user, amount, currency, payment_term, date=None,
-            context=None):
+    def compute(self, amount, currency, payment_term, date=None):
         '''
         Return list with (date, amount) for each payment term lines
         '''
@@ -45,23 +45,20 @@ class PaymentTerm(ModelSQL, ModelView):
 
         res = []
         if date is None:
-            date = date_obj.today(cursor, user, context=context)
+            date = date_obj.today()
         remainder = amount
         for line in payment_term.lines:
-            value = type_obj.get_value(cursor, user, line, remainder, currency,
-                    context)
-            value_date = delay_obj.get_date(cursor, user, line, date, context)
+            value = type_obj.get_value(line, remainder, currency)
+            value_date = delay_obj.get_date(line, date)
             if not value or not value_date:
                 if (not remainder) and line.amount:
-                    self.raise_user_error(cursor, 'invalid_line',
-                            context=context)
+                    self.raise_user_error('invalid_line')
                 else:
                     continue
             res.append((value_date, value))
             remainder -= value
-        if not currency_obj.is_zero(cursor, user, currency, remainder):
-            self.raise_user_error(cursor, 'missing_remainder',
-                    context=context)
+        if not currency_obj.is_zero(currency, remainder):
+            self.raise_user_error('missing_remainder')
         return res
 
 PaymentTerm()
@@ -81,16 +78,15 @@ class PaymentTermLineType(ModelSQL, ModelView):
         ]
         self._order.insert(0, ('name', 'ASC'))
 
-    def get_value(self, cursor, user, line, amount, currency, context=None):
+    def get_value(self, line, amount, currency):
         currency_obj = self.pool.get('currency.currency')
         if line.type == 'fixed':
-            return currency_obj.compute(cursor, user, line.currency,
-                    line.amount, currency, context=context)
+            return currency_obj.compute(line.currency, line.amount, currency)
         elif line.type == 'percent':
-            return currency_obj.round(cursor, user, currency,
+            return currency_obj.round(currency,
                     amount * line.percentage / Decimal('100'))
         elif line.type == 'remainder':
-            return currency_obj.round(cursor, user, currency, amount)
+            return currency_obj.round(currency, amount)
         return None
 
 PaymentTermLineType()
@@ -110,7 +106,7 @@ class PaymentTermLineDelay(ModelSQL, ModelView):
         ]
         self._order.insert(0, ('name', 'ASC'))
 
-    def get_date(self, cursor, user, line, date, context=None):
+    def get_date(self, line, date):
         value = None
         if line.delay in ('net_days', 'end_month'):
             value = date + relativedelta(days=line.days)
@@ -155,8 +151,9 @@ class PaymentTermLine(ModelSQL, ModelView):
         super(PaymentTermLine, self).__init__()
         self._order.insert(0, ('sequence', 'ASC'))
 
-    def init(self, cursor, module_name):
-        super(PaymentTermLine, self).init(cursor, module_name)
+    def init(self, module_name):
+        super(PaymentTermLine, self).init(module_name)
+        cursor = Transaction().cursor
         table = TableHandler(cursor, self, module_name)
 
         # Migration from 1.0 percent change into percentage
@@ -165,26 +162,25 @@ class PaymentTermLine(ModelSQL, ModelView):
                     'SET percentage = percent * 100')
             table.drop_column('percent', exception=True)
 
-    def default_type(self, cursor, user, context=None):
+    def default_type(self):
         return 'remainder'
 
-    def default_delay(self, cursor, user, context=None):
+    def default_delay(self):
         return 'net_days'
 
-    def get_type(self, cursor, user, context=None):
+    def get_type(self):
         type_obj = self.pool.get('account.invoice.payment_term.line.type')
-        type_ids = type_obj.search(cursor, user, [], context=context)
-        types = type_obj.browse(cursor, user, type_ids, context=context)
+        type_ids = type_obj.search([])
+        types = type_obj.browse(type_ids)
         return [(x.code, x.name) for x in types]
 
-    def get_delay(self, cursor, user, context=None):
+    def get_delay(self):
         delay_obj = self.pool.get('account.invoice.payment_term.line.delay')
-        delay_ids = delay_obj.search(cursor, user, [], context=context)
-        delays = delay_obj.browse(cursor, user, delay_ids,
-                context=context)
+        delay_ids = delay_obj.search([])
+        delays = delay_obj.browse(delay_ids)
         return [(x.code, x.name) for x in delays]
 
-    def on_change_type(self, cursor, user, vals, context=None):
+    def on_change_type(self, vals):
         if not 'type' in vals:
             return {}
         res = {}
@@ -195,17 +191,16 @@ class PaymentTermLine(ModelSQL, ModelView):
             res['percentage'] =  Decimal('0.0')
         return res
 
-    def on_change_with_currency_digits(self, cursor, user, vals, context=None):
+    def on_change_with_currency_digits(self, vals):
         currency_obj = self.pool.get('currency.currency')
         if vals.get('currency'):
-            currency = currency_obj.browse(cursor, user, vals['currency'],
-                    context=context)
+            currency = currency_obj.browse(vals['currency'])
             return currency.digits
         return 2
 
-    def get_currency_digits(self, cursor, user, ids, name, context=None):
+    def get_currency_digits(self, ids, name):
         res = {}
-        for line in self.browse(cursor, user, ids, context=context):
+        for line in self.browse(ids):
             if line.currency:
                 res[line.id] = line.currency.digits
             else:
